summaryrefslogtreecommitdiff
path: root/drivers/gpu/drm/amd/amdgpu/amdgpu_mode.h
diff options
context:
space:
mode:
authorAric Cyr <aric.cyr@amd.com>2016-12-29 15:27:12 -0500
committerAlex Deucher <alexander.deucher@amd.com>2017-09-26 17:09:40 -0400
commitab2541b67395088b9de8ebf3943ef9ef86bccc41 (patch)
treec4f25d2560d5f619d8a151f65c43a99f86592267 /drivers/gpu/drm/amd/amdgpu/amdgpu_mode.h
parent624d7c4708b27be2dc095579394efadd80f090dd (diff)
drm/amd/display: Remove dc_target object
dc_target does not fit well into DRM framework so removed it. This will prevent the driver from leveraging the pipe-split code for tiled displays, so will have to be handled at a higher level. Most places that used dc_target now directly use dc_stream instead. Signed-off-by: Aric Cyr <aric.cyr@amd.com> Acked-by: Harry Wentland <Harry.Wentland@amd.com> Signed-off-by: Alex Deucher <alexander.deucher@amd.com>
Diffstat (limited to 'drivers/gpu/drm/amd/amdgpu/amdgpu_mode.h')
-rw-r--r--drivers/gpu/drm/amd/amdgpu/amdgpu_mode.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/drivers/gpu/drm/amd/amdgpu/amdgpu_mode.h b/drivers/gpu/drm/amd/amdgpu/amdgpu_mode.h
index 3a3adfa16ada..0d92126b4c4a 100644
--- a/drivers/gpu/drm/amd/amdgpu/amdgpu_mode.h
+++ b/drivers/gpu/drm/amd/amdgpu/amdgpu_mode.h
@@ -428,8 +428,8 @@ struct amdgpu_crtc {
int otg_inst;
uint32_t flip_flags;
- /* After Set Mode target will be non-NULL */
- struct dc_target *target;
+ /* After Set Mode stream will be non-NULL */
+ const struct dc_stream *stream;
};
struct amdgpu_encoder_atom_dig {
@@ -550,7 +550,7 @@ struct amdgpu_connector {
const struct dc_sink *dc_sink;
const struct dc_link *dc_link;
const struct dc_sink *dc_em_sink;
- const struct dc_target *target;
+ const struct dc_stream *stream;
void *con_priv;
bool dac_load_detect;
bool detected_by_load; /* if the connection status was determined by load */